function ExponentialRK2Conv
% this code calculates the order of exponentialRK2 using a reference
% solution for Zeeman's Heartbeat model obtained using ode23s.
  
  alpha = 0.75; % free-parameter in ExponentialRK2.

  beta = 0.01;
  heartalpha = 3;

  % Zeeman's Heartbeat model: Example 11, Section 1.2.3
  f = @(t,y) [ -y(1)^3 + heartalpha*y(1) - y(2);
               beta*y(1)];

  df = @(t,y) [ -3*y(1)^2 + heartalpha, -1;
               beta, 0 ];
  
  y0 = [1; 0];
  T = [0 100];
  h = 2.^-[2:6];

  options = odeset('RelTol',1e-12,'AbsTol',1e-12,'Jacobian',df);
  [tGood,yGood] = ode23s(f,T,y0,options);

  disp('ode23s done...');
  
  yGood = yGood.'; % matlab compatibility
  
  err = nan(size(h));

  for j=1:length(h)
    [t,y] = exponentialRK2(f,df,y0,T,h(j),alpha);
    err(j) = norm( y(1,end) - yGood(1,end) );
  end

  figure;
  plot(t,y(1,:),'ro');
  hold on;
  plot(tGood, yGood(1,:), 'g-','LineWidth',1.1); 
  title('Solution to Zeeman''s Heartbeat Model using Exponential RK2');
  xlabel('t');
  ylabel('y(t)');
  legend(['Exponential RK2, h=' num2str(h(end))] ,'ode23s');
  
  figure;
  loglog(h,err,'bx:')
  grid on;
  title('Log-Log Plot of Error against Step-Size for Exponential RK2');
  xlabel('h');
  ylabel('error');

  fit = polyfit(log(h),log(err),1);
  fprintf('calculated numerical convergence orders: %f\n',fit(1));
